# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: brymck/risk/v1/covariance.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='brymck/risk/v1/covariance.proto',
  package='brymck.risk.v1',
  syntax='proto3',
  serialized_options=_b('\n\031com.github.brymck.risk.v1B\017CovarianceProtoP\001Z\006riskv1\242\002\003BRX\252\002\016Brymck.Risk.V1\312\002\016Brymck\\Risk\\V1'),
  serialized_pb=_b('\n\x1f\x62rymck/risk/v1/covariance.proto\x12\x0e\x62rymck.risk.v1\"P\n\x0e\x43ovariancePair\x12\x14\n\x0csecurity_id1\x18\x01 \x01(\x04\x12\x14\n\x0csecurity_id2\x18\x02 \x01(\x04\x12\x12\n\ncovariance\x18\x03 \x01(\x01\x42^\n\x19\x63om.github.brymck.risk.v1B\x0f\x43ovarianceProtoP\x01Z\x06riskv1\xa2\x02\x03\x42RX\xaa\x02\x0e\x42rymck.Risk.V1\xca\x02\x0e\x42rymck\\Risk\\V1b\x06proto3')
)




_COVARIANCEPAIR = _descriptor.Descriptor(
  name='CovariancePair',
  full_name='brymck.risk.v1.CovariancePair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='security_id1', full_name='brymck.risk.v1.CovariancePair.security_id1', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='security_id2', full_name='brymck.risk.v1.CovariancePair.security_id2', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='covariance', full_name='brymck.risk.v1.CovariancePair.covariance', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51,
  serialized_end=131,
)

DESCRIPTOR.message_types_by_name['CovariancePair'] = _COVARIANCEPAIR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CovariancePair = _reflection.GeneratedProtocolMessageType('CovariancePair', (_message.Message,), dict(
  DESCRIPTOR = _COVARIANCEPAIR,
  __module__ = 'brymck.risk.v1.covariance_pb2'
  # @@protoc_insertion_point(class_scope:brymck.risk.v1.CovariancePair)
  ))
_sym_db.RegisterMessage(CovariancePair)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: brymck/risk/v1/return_time_series_entry.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from brymck.dates.v1 import date_pb2 as brymck_dot_dates_dot_v1_dot_date__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='brymck/risk/v1/return_time_series_entry.proto',
  package='brymck.risk.v1',
  syntax='proto3',
  serialized_options=_b('\n\031com.github.brymck.risk.v1B\032ReturnTimeSeriesEntryProtoP\001Z\006riskv1\242\002\003BRX\252\002\016Brymck.Risk.V1\312\002\016Brymck\\Risk\\V1'),
  serialized_pb=_b('\n-brymck/risk/v1/return_time_series_entry.proto\x12\x0e\x62rymck.risk.v1\x1a\x1a\x62rymck/dates/v1/date.proto\"L\n\x15ReturnTimeSeriesEntry\x12#\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x15.brymck.dates.v1.Date\x12\x0e\n\x06return\x18\x02 \x01(\x01\x42i\n\x19\x63om.github.brymck.risk.v1B\x1aReturnTimeSeriesEntryProtoP\x01Z\x06riskv1\xa2\x02\x03\x42RX\xaa\x02\x0e\x42rymck.Risk.V1\xca\x02\x0e\x42rymck\\Risk\\V1b\x06proto3')
  ,
  dependencies=[brymck_dot_dates_dot_v1_dot_date__pb2.DESCRIPTOR,])




_RETURNTIMESERIESENTRY = _descriptor.Descriptor(
  name='ReturnTimeSeriesEntry',
  full_name='brymck.risk.v1.ReturnTimeSeriesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='brymck.risk.v1.ReturnTimeSeriesEntry.date', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='return', full_name='brymck.risk.v1.ReturnTimeSeriesEntry.return', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=93,
  serialized_end=169,
)

_RETURNTIMESERIESENTRY.fields_by_name['date'].message_type = brymck_dot_dates_dot_v1_dot_date__pb2._DATE
DESCRIPTOR.message_types_by_name['ReturnTimeSeriesEntry'] = _RETURNTIMESERIESENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ReturnTimeSeriesEntry = _reflection.GeneratedProtocolMessageType('ReturnTimeSeriesEntry', (_message.Message,), dict(
  DESCRIPTOR = _RETURNTIMESERIESENTRY,
  __module__ = 'brymck.risk.v1.return_time_series_entry_pb2'
  # @@protoc_insertion_point(class_scope:brymck.risk.v1.ReturnTimeSeriesEntry)
  ))
_sym_db.RegisterMessage(ReturnTimeSeriesEntry)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
